@@ -1,8 +1,9 @@
 import time
+import datetime
 from datetime import datetime
 from threading import Thread
 
-from src.cloudio_connector import AttributeListener, CloudioConnector, AttributeId
+from src.cloudio_connector import AttributeListener, CloudioConnector, AttributeId, TimeSeries
 
 
 class Tester(AttributeListener):
@@ -14,11 +15,9 @@ class Tester(AttributeListener):
         attr = [
             AttributeId(uuid=cc.get_uuid('demo'), node='myNode', objects=['myObject'], attribute='mySetPoint'),
             AttributeId(uuid=cc.get_uuid('demo'), node='myNode', objects=['myObject'], attribute='myInt')]
-        while True:
-            cc.subscribe_to_attribute(attr[0])
-            time.sleep(10)
-            # cc.subscribe_to_attributes([])
-            # time.sleep(10)
+        cc.subscribe_to_attribute(attr[0])
+        tm = TimeSeries(attr[0], start=datetime.now() - datetime.timedelta(hours=2), stop=datetime.now(), resample='15m')
+        data = cc.get_time_series(tm)
 
 
     def attribute_has_changed(self, attribute: AttributeId, value):
